==> decoration-ioc-1.0.2.tgz: package/lib/serviceCollection.js <==
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
var arrays_1 = require('./base/arrays');
var ServiceCollection = (function () {
    function ServiceCollection() {
        var entries = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            entries[_i - 0] = arguments[_i];
        }
        this._entries = [];
        for (var _c = 0, entries_1 = entries; _c < entries_1.length; _c++) {
            var entry = entries_1[_c];
            this.set(entry[0], entry[1]);
        }
    }
    ServiceCollection.prototype.set = function (id, instanceOrDescriptor) {
        var entry = [id, instanceOrDescriptor];
        var idx = arrays_1.binarySearch(this._entries, entry, ServiceCollection._entryCompare);
        if (idx < 0) {
            // new element
            this._entries.splice(~idx, 0, entry);
        }
        else {
            var old = this._entries[idx];
            this._entries[idx] = entry;
            return old[1];
        }
    };
    ServiceCollection.prototype.forEach = function (callback) {
        for (var _i = 0, _c = this._entries; _i < _c.length; _i++) {
            var entry = _c[_i];
            var id = entry[0], instanceOrDescriptor = entry[1];
            callback(id, instanceOrDescriptor);
        }
    };
    ServiceCollection.prototype.has = function (id) {
        return arrays_1.binarySearch(this._entries, ServiceCollection._searchEntry(id), ServiceCollection._entryCompare) >= 0;
    };
    ServiceCollection.prototype.get = function (id) {
        var idx = arrays_1.binarySearch(this._entries, ServiceCollection._searchEntry(id), ServiceCollection._entryCompare);
        if (idx >= 0) {
            return this._entries[idx][1];
        }
    };
    ServiceCollection._searchEntry = function (id) {
        ServiceCollection._dummy[0] = id;
        return ServiceCollection._dummy;
    };
    ServiceCollection._entryCompare = function (a, b) {
        var _a = a[0].toString();
        var _b = b[0].toString();
        if (_a < _b) {
            return -1;
        }
        else if (_a > _b) {
            return 1;
        }
        else {
            return 0;
        }
    };
    ServiceCollection._dummy = [undefined, undefined];
    return ServiceCollection;
}());
exports.ServiceCollection = ServiceCollection;

==> decoration-ioc-1.1.0.tgz: package/lib/serviceCollection.js <==
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
"use strict";
var arrays_1 = require("./base/arrays");
var ServiceCollection = (function () {
    function ServiceCollection() {
        var entries = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            entries[_i - 0] = arguments[_i];
        }
        this._entries = [];
        for (var _c = 0, entries_1 = entries; _c < entries_1.length; _c++) {
            var entry = entries_1[_c];
            this.set(entry[0], entry[1]);
        }
    }
    ServiceCollection.prototype.set = function (id, instanceOrDescriptor) {
        var entry = [id, instanceOrDescriptor];
        var idx = arrays_1.binarySearch(this._entries, entry, ServiceCollection._entryCompare);
        if (idx < 0) {
            // new element
            this._entries.splice(~idx, 0, entry);
        }
        else {
            var old = this._entries[idx];
            this._entries[idx] = entry;
            return old[1];
        }
    };
    ServiceCollection.prototype.forEach = function (callback) {
        for (var _i = 0, _c = this._entries; _i < _c.length; _i++) {
            var entry = _c[_i];
            var id = entry[0], instanceOrDescriptor = entry[1];
            callback(id, instanceOrDescriptor);
        }
    };
    ServiceCollection.prototype.has = function (id) {
        return arrays_1.binarySearch(this._entries, ServiceCollection._searchEntry(id), ServiceCollection._entryCompare) >= 0;
    };
    ServiceCollection.prototype.get = function (id) {
        var idx = arrays_1.binarySearch(this._entries, ServiceCollection._searchEntry(id), ServiceCollection._entryCompare);
        if (idx >= 0) {
            return this._entries[idx][1];
        }
    };
    ServiceCollection._searchEntry = function (id) {
        ServiceCollection._dummy[0] = id;
        return ServiceCollection._dummy;
    };
    ServiceCollection._entryCompare = function (a, b) {
        var _a = a[0].toString();
        var _b = b[0].toString();
        if (_a < _b) {
            return -1;
        }
        else if (_a > _b) {
            return 1;
        }
        else {
            return 0;
        }
    };
    ServiceCollection._dummy = [undefined, undefined];
    return ServiceCollection;
}());
exports.ServiceCollection = ServiceCollection;
